@@ -13,17 +13,17 @@
 %                           Write A Preview Image.                            %
 %                                                                             %
 %                              Software Design                                %
-%                                John Cristy                                  %
+%                                   Cristy                                    %
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/script/license.php                            %
+%    https://imagemagick.org/script/license.php                               %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -54,9 +54,11 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
+#include "magick/pixel-accessor.h"
+#include "magick/quantum-private.h"
 #include "magick/resize.h"
 #include "magick/resource_.h"
-#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/module.h"
@@ -89,10 +91,10 @@ static MagickBooleanType
 %
 %  The format of the RegisterPREVIEWImage method is:
 %
-%      unsigned long RegisterPREVIEWImage(void)
+%      size_t RegisterPREVIEWImage(void)
 %
 */
-ModuleExport unsigned long RegisterPREVIEWImage(void)
+ModuleExport size_t RegisterPREVIEWImage(void)
 {
   MagickInfo
     *entry;
@@ -100,9 +102,10 @@ ModuleExport unsigned long RegisterPREVIEWImage(void)
   entry=SetMagickInfo("PREVIEW");
   entry->encoder=(EncodeImageHandler *) WritePreviewImage;
   entry->adjoin=MagickFalse;
+  entry->format_type=ImplicitFormatType;
   entry->description=ConstantString(
     "Show a preview an image enhancement, effect, or f/x");
-  entry->module=ConstantString("PREVIEW");
+  entry->magick_module=ConstantString("PREVIEW");
   (void) RegisterMagickInfo(entry);
   return(MagickImageCoderSignature);
 }
@@ -153,11 +156,10 @@ ModuleExport void UnregisterPREVIEWImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WritePreviewImage(const ImageInfo *image_info,
   Image *image)
@@ -175,9 +177,9 @@ static MagickBooleanType WritePreviewImage(const ImageInfo *image_info,
     Open output image file.
   */
   assert(image_info != (const ImageInfo *) NULL);
-  assert(image_info->signature == MagickSignature);
+  assert(image_info->signature == MagickCoreSignature);
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   preview_image=PreviewImage(image,image_info->preview_type,&image->exception);
@@ -186,9 +188,11 @@ static MagickBooleanType WritePreviewImage(const ImageInfo *image_info,
   (void) CopyMagickString(preview_image->filename,image_info->filename,
     MaxTextExtent);
   write_info=CloneImageInfo(image_info);
-  (void) SetImageInfo(write_info,MagickTrue,&image->exception);
-  if (LocaleCompare(write_info->magick,"PREVIEW") == 0)
-    (void) FormatMagickString(preview_image->filename,MaxTextExtent,
+  *write_info->magick='\0';
+  (void) SetImageInfo(write_info,1,&image->exception);
+  if ((*write_info->magick == '\0') ||
+      (LocaleCompare(write_info->magick,"PREVIEW") == 0))
+    (void) FormatLocaleString(preview_image->filename,MaxTextExtent,
       "miff:%s",image_info->filename);
   status=WriteImage(write_info,preview_image);
   preview_image=DestroyImage(preview_image);
