@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
-  You may not use this file except in compliance with the License.
+  You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
   
-    http://www.imagemagick.org/script/license.php
+    https://imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,15 +15,16 @@
 
   MagickCore X11 window methods.
 */
-#ifndef _MAGICKCORE_XWINDOW_PRIVATE_H
-#define _MAGICKCORE_XWINDOW_PRIVATE_H
+#ifndef MAGICKCORE_XWINDOW_PRIVATE_H
+#define MAGICKCORE_XWINDOW_PRIVATE_H
 
-#if defined(__cplusplus) || defined(c_plusplus)
-extern "C" {
-#endif
-
-#if defined(HasX11)
+#include "magick/draw.h"
+#include "magick/exception.h"
+#include "magick/geometry.h"
+#include "magick/nt-base-private.h"
+#include "magick/quantize.h"
 
+#if defined(MAGICKCORE_X11_DELEGATE)
 #include <X11/Xos.h>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
@@ -31,9 +32,13 @@ extern "C" {
 #include <X11/keysym.h>
 #include <X11/Xresource.h>
 #include <X11/Xutil.h>
-#include "magick/exception.h"
-#include "magick/geometry.h"
-#include "magick/quantize.h"
+#endif
+
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
+#if defined(MAGICKCORE_X11_DELEGATE)
 
 #if defined(__cplusplus) || defined(c_plusplus)
 # define klass  c_class
@@ -41,27 +46,6 @@ extern "C" {
 # define klass  class
 #endif
 
-/*
-  Invoke pre-X11R6 ICCCM routines if XlibSpecificationRelease is not 6.
-*/
-#if XlibSpecificationRelease < 6
-#if !defined(PRE_R6_ICCCM)
-#define PRE_R6_ICCCM
-#endif
-#endif
-/*
-  Invoke pre-X11R5 ICCCM routines if XlibSpecificationRelease is not defined.
-*/
-#if !defined(XlibSpecificationRelease)
-#define PRE_R5_ICCCM
-#endif
-/*
-  Invoke pre-X11R4 ICCCM routines if PWinGravity is not defined.
-*/
-#if !defined(PWinGravity)
-#define PRE_R4_ICCCM
-#endif
-
 #define MaxIconSize  96
 #define MaxNumberPens  11
 #define MaxNumberFonts  11
@@ -71,14 +55,14 @@ extern "C" {
 #define ThrowXWindowException(severity,tag,context) \
 { \
   ExceptionInfo \
-    exception; \
+    *exception; \
  \
-  GetExceptionInfo(&exception); \
-  (void) ThrowMagickException(&exception,GetMagickModule(),severity, \
+  exception=AcquireExceptionInfo(); \
+  (void) ThrowMagickException(exception,GetMagickModule(),severity, \
     tag == (const char *) NULL ? "unknown" : tag,"`%s': %s",context, \
     strerror(errno)); \
-  CatchException(&exception); \
-  (void) DestroyExceptionInfo(&exception); \
+  CatchException(exception); \
+  (void) DestroyExceptionInfo(exception); \
 }
 #define ThrowXWindowFatalException(severity,tag,context) \
 { \
@@ -208,8 +192,10 @@ typedef struct _XAnnotateInfo
 
 typedef struct _XPixelInfo
 {
+  ssize_t
+    colors;
+
   unsigned long
-    colors,
     *pixels;
 
   XColor
@@ -246,7 +232,7 @@ typedef struct _XResourceInfo
   QuantizeInfo
     *quantize_info;
 
-  unsigned long
+  size_t
     colors;
 
   MagickBooleanType
@@ -266,7 +252,7 @@ typedef struct _XResourceInfo
   unsigned int
     border_width;
 
-  unsigned long
+  size_t
     delay;
 
   MagickBooleanType
@@ -322,7 +308,7 @@ typedef struct _XResourceInfo
     use_pixmap,
     use_shared_memory;
 
-  unsigned long
+  size_t
     undo_cache;
 
   char
@@ -384,7 +370,7 @@ typedef struct _XWindowInfo
     *icon_geometry,
     *crop_geometry;
 
-  unsigned long
+  size_t
     data,
     flags;
 
@@ -431,7 +417,7 @@ typedef struct _XWindowInfo
   void
     *segment_info;
 
-  unsigned long
+  long
     mask;
 
   MagickBooleanType
@@ -517,6 +503,7 @@ extern MagickExport int
 
 extern MagickExport MagickBooleanType
   XAnnotateImage(Display *,const XPixelInfo *,XAnnotateInfo *,Image *),
+  XComponentGenesis(void),
   XDrawImage(Display *,const XPixelInfo *,XDrawInfo *,Image *),
   XGetWindowColor(Display *,XWindows *,char *),
   XMagickProgressMonitor(const char *,const MagickOffsetType,
@@ -532,12 +519,13 @@ extern MagickExport void
   XBestPixel(Display *,const Colormap,XColor *,unsigned int,XColor *),
   XCheckRefreshWindows(Display *,XWindows *),
   XClientMessage(Display *,const Window,const Atom,const Atom,const Time),
+  XComponentTerminus(void),
   XConfigureImageColormap(Display *,XResourceInfo *,XWindows *,Image *),
   XConstrainWindowPosition(Display *,XWindowInfo *),
-  XDelay(Display *,const unsigned long),
+  XDelay(Display *,const size_t),
+  XDisplayImageInfo(Display *,const XResourceInfo *,XWindows *,Image *,Image *),
   XDestroyResourceInfo(XResourceInfo *),
   XDestroyWindowColors(Display *,Window),
-  XDisplayImageInfo(Display *,const XResourceInfo *,XWindows *,Image *,Image *),
   XFreeResources(Display *,XVisualInfo *,XStandardColormap *,XPixelInfo *,
     XFontStruct *,XResourceInfo *,XWindowInfo *),
   XFreeStandardColormap(Display *,const XVisualInfo *,XStandardColormap *,
@@ -549,7 +537,7 @@ extern MagickExport void
   XGetPixelPacket(Display *,const XVisualInfo *,const XStandardColormap *,
     const XResourceInfo *,Image *,XPixelInfo *),
   XGetMapInfo(const XVisualInfo *,const Colormap,XStandardColormap *),
-  XGetResourceInfo(XrmDatabase,const char *,XResourceInfo *),
+  XGetResourceInfo(const ImageInfo *,XrmDatabase,const char *,XResourceInfo *),
   XGetWindowInfo(Display *,XVisualInfo *,XStandardColormap *,XPixelInfo *,
     XFontStruct *,XResourceInfo *,XWindowInfo *),
   XMakeMagnifyImage(Display *,XWindows *),
@@ -565,7 +553,7 @@ extern MagickExport void
   XWarning(const ExceptionType,const char *,const char *);
 
 extern MagickExport Window
-  XWindowByID(Display *,const Window,const unsigned long),
+  XWindowByID(Display *,const Window,const size_t),
   XWindowByName(Display *,const Window,const char *),
   XWindowByProperty(Display *,const Window,const Atom);
 
@@ -587,12 +575,16 @@ static inline MagickRealType XPixelIntensity(const XColor *pixel)
   MagickRealType
     intensity;
 
-  intensity=0.299*pixel->red+0.587*pixel->green+0.114*pixel->blue;
+  if ((pixel->red  == pixel->green) && (pixel->green == pixel->blue))
+    return((MagickRealType) pixel->red);
+  intensity=0.21265*pixel->red+0.715158*pixel->green+0.072186*pixel->blue;
   return(intensity);
 }
-
 #endif
 
+extern MagickPrivate MagickBooleanType
+  XRenderImage(Image *,const DrawInfo *,const PointInfo *,TypeMetric *);
+
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
